/*
** EPITECH PROJECT, 2018
** task01
** File description:
** I do task
*/

#ifndef __MEMORY__
# define __MEMORY__

#include "lib/s_sfml.h"
int check_map(scene_t *scene);
void free_scene(scene_t *scene);
camera_t *init_camera(scene_t *scene);
level_t *load_map(const char *file);
wall_t *init_wall(player_t *player);
player_t *init_player(level_t *level);
thrower_t **init_thrower(level_t *level);
object_t *init_object(thrower_t *thrower);
message_t **load_message(scene_t *scene, uint8_t type);
scene_t *new_scene(char *map_name, uint8_t object);
sound_t *init_music(char *music_name);

#endif
